<a id="types-aiobotocore-proton"></a>

# types-aiobotocore-proton

[![PyPI - types-aiobotocore-proton](https://img.shields.io/pypi/v/types-aiobotocore-proton.svg?color=blue)](https://pypi.org/project/types-aiobotocore-proton)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-proton.svg?color=blue)](https://pypi.org/project/types-aiobotocore-proton)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-proton?color=blue)](https://pypistats.org/packages/types-aiobotocore-proton)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.Proton 2.3.4](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.10.0](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-proton docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_proton/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-proton](#types-aiobotocore-proton)
  - [How to install](#how-to-install)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `Proton` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[proton]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[proton]'


# standalone installation
python -m pip install types-aiobotocore-proton
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-proton
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[proton]` in your environment:

```bash
python -m pip install 'types-aiobotocore[proton]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[proton]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[proton]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[proton]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[proton]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[proton]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[proton]` in your environment:

```bash
python -m pip install 'types-aiobotocore[proton]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[proton]` in your environment:

```bash
python -m pip install 'types-aiobotocore[proton]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ProtonClient` provides annotations for `session.create_client("proton")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_proton import ProtonClient

session = get_session()
async with session.create_client("proton") as client:
    client: ProtonClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_proton.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_proton import ProtonClient
from types_aiobotocore_proton.paginator import (
    ListEnvironmentAccountConnectionsPaginator,
    ListEnvironmentOutputsPaginator,
    ListEnvironmentProvisionedResourcesPaginator,
    ListEnvironmentTemplateVersionsPaginator,
    ListEnvironmentTemplatesPaginator,
    ListEnvironmentsPaginator,
    ListRepositoriesPaginator,
    ListRepositorySyncDefinitionsPaginator,
    ListServiceInstanceOutputsPaginator,
    ListServiceInstanceProvisionedResourcesPaginator,
    ListServiceInstancesPaginator,
    ListServicePipelineOutputsPaginator,
    ListServicePipelineProvisionedResourcesPaginator,
    ListServiceTemplateVersionsPaginator,
    ListServiceTemplatesPaginator,
    ListServicesPaginator,
    ListTagsForResourcePaginator,
)

session = get_session()
async with session.create_client("proton") as client:
    client: ProtonClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_environment_account_connections_paginator: ListEnvironmentAccountConnectionsPaginator = client.get_paginator("list_environment_account_connections")
        list_environment_outputs_paginator: ListEnvironmentOutputsPaginator = client.get_paginator("list_environment_outputs")
        list_environment_provisioned_resources_paginator: ListEnvironmentProvisionedResourcesPaginator = client.get_paginator("list_environment_provisioned_resources")
        list_environment_template_versions_paginator: ListEnvironmentTemplateVersionsPaginator = client.get_paginator("list_environment_template_versions")
        list_environment_templates_paginator: ListEnvironmentTemplatesPaginator = client.get_paginator("list_environment_templates")
        list_environments_paginator: ListEnvironmentsPaginator = client.get_paginator("list_environments")
        list_repositories_paginator: ListRepositoriesPaginator = client.get_paginator("list_repositories")
        list_repository_sync_definitions_paginator: ListRepositorySyncDefinitionsPaginator = client.get_paginator("list_repository_sync_definitions")
        list_service_instance_outputs_paginator: ListServiceInstanceOutputsPaginator = client.get_paginator("list_service_instance_outputs")
        list_service_instance_provisioned_resources_paginator: ListServiceInstanceProvisionedResourcesPaginator = client.get_paginator("list_service_instance_provisioned_resources")
        list_service_instances_paginator: ListServiceInstancesPaginator = client.get_paginator("list_service_instances")
        list_service_pipeline_outputs_paginator: ListServicePipelineOutputsPaginator = client.get_paginator("list_service_pipeline_outputs")
        list_service_pipeline_provisioned_resources_paginator: ListServicePipelineProvisionedResourcesPaginator = client.get_paginator("list_service_pipeline_provisioned_resources")
        list_service_template_versions_paginator: ListServiceTemplateVersionsPaginator = client.get_paginator("list_service_template_versions")
        list_service_templates_paginator: ListServiceTemplatesPaginator = client.get_paginator("list_service_templates")
        list_services_paginator: ListServicesPaginator = client.get_paginator("list_services")
        list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
    ```


### Waiters annotations

`types_aiobotocore_proton.waiter` module contains type annotations for all waiters.

```python
from aiobotocore.session import get_session

from types_aiobotocore_proton.client import ProtonClient
from types_aiobotocore_proton.waiter import (
    EnvironmentDeployedWaiter,
    EnvironmentTemplateVersionRegisteredWaiter,
    ServiceCreatedWaiter,
    ServiceDeletedWaiter,
    ServiceInstanceDeployedWaiter,
    ServicePipelineDeployedWaiter,
    ServiceTemplateVersionRegisteredWaiter,
    ServiceUpdatedWaiter,
)

session = get_session()
async with session.create_client("proton") as client:
    client: ProtonClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        environment_deployed_waiter: EnvironmentDeployedWaiter = client.get_waiter("environment_deployed")
        environment_template_version_registered_waiter: EnvironmentTemplateVersionRegisteredWaiter = client.get_waiter("environment_template_version_registered")
        service_created_waiter: ServiceCreatedWaiter = client.get_waiter("service_created")
        service_deleted_waiter: ServiceDeletedWaiter = client.get_waiter("service_deleted")
        service_instance_deployed_waiter: ServiceInstanceDeployedWaiter = client.get_waiter("service_instance_deployed")
        service_pipeline_deployed_waiter: ServicePipelineDeployedWaiter = client.get_waiter("service_pipeline_deployed")
        service_template_version_registered_waiter: ServiceTemplateVersionRegisteredWaiter = client.get_waiter("service_template_version_registered")
        service_updated_waiter: ServiceUpdatedWaiter = client.get_waiter("service_updated")
    ```





<a id="literals"></a>

### Literals

`types_aiobotocore_proton.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_proton.literals import (
    DeploymentStatusType,
    DeploymentUpdateTypeType,
    EnvironmentAccountConnectionRequesterAccountTypeType,
    EnvironmentAccountConnectionStatusType,
    EnvironmentDeployedWaiterName,
    EnvironmentTemplateVersionRegisteredWaiterName,
    ListEnvironmentAccountConnectionsPaginatorName,
    ListEnvironmentOutputsPaginatorName,
    ListEnvironmentProvisionedResourcesPaginatorName,
    ListEnvironmentTemplateVersionsPaginatorName,
    ListEnvironmentTemplatesPaginatorName,
    ListEnvironmentsPaginatorName,
    ListRepositoriesPaginatorName,
    ListRepositorySyncDefinitionsPaginatorName,
    ListServiceInstanceOutputsPaginatorName,
    ListServiceInstanceProvisionedResourcesPaginatorName,
    ListServiceInstancesPaginatorName,
    ListServicePipelineOutputsPaginatorName,
    ListServicePipelineProvisionedResourcesPaginatorName,
    ListServiceTemplateVersionsPaginatorName,
    ListServiceTemplatesPaginatorName,
    ListServicesPaginatorName,
    ListTagsForResourcePaginatorName,
    ProvisionedResourceEngineType,
    ProvisioningType,
    RepositoryProviderType,
    RepositorySyncStatusType,
    ResourceDeploymentStatusType,
    ResourceSyncStatusType,
    ServiceCreatedWaiterName,
    ServiceDeletedWaiterName,
    ServiceInstanceDeployedWaiterName,
    ServicePipelineDeployedWaiterName,
    ServiceStatusType,
    ServiceTemplateVersionRegisteredWaiterName,
    ServiceUpdatedWaiterName,
    SyncTypeType,
    TemplateTypeType,
    TemplateVersionStatusType,
    ProtonServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    WaiterName,
)

def check_value(value: DeploymentStatusType) -> bool:
    ...
````

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_proton.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_proton.type_defs import (
    AcceptEnvironmentAccountConnectionInputRequestTypeDef,
    EnvironmentAccountConnectionTypeDef,
    ResponseMetadataTypeDef,
    RepositoryBranchTypeDef,
    CancelEnvironmentDeploymentInputRequestTypeDef,
    CancelServiceInstanceDeploymentInputRequestTypeDef,
    ServiceInstanceTypeDef,
    CancelServicePipelineDeploymentInputRequestTypeDef,
    ServicePipelineTypeDef,
    CompatibleEnvironmentTemplateInputTypeDef,
    CompatibleEnvironmentTemplateTypeDef,
    TagTypeDef,
    RepositoryBranchInputTypeDef,
    EnvironmentTemplateTypeDef,
    EnvironmentTemplateVersionTypeDef,
    CreateRepositoryInputRequestTypeDef,
    RepositoryTypeDef,
    ServiceTemplateTypeDef,
    CreateTemplateSyncConfigInputRequestTypeDef,
    TemplateSyncConfigTypeDef,
    DeleteEnvironmentAccountConnectionInputRequestTypeDef,
    DeleteEnvironmentInputRequestTypeDef,
    DeleteEnvironmentTemplateInputRequestTypeDef,
    DeleteEnvironmentTemplateVersionInputRequestTypeDef,
    DeleteRepositoryInputRequestTypeDef,
    DeleteServiceInputRequestTypeDef,
    DeleteServiceTemplateInputRequestTypeDef,
    DeleteServiceTemplateVersionInputRequestTypeDef,
    DeleteTemplateSyncConfigInputRequestTypeDef,
    EnvironmentAccountConnectionSummaryTypeDef,
    EnvironmentSummaryTypeDef,
    EnvironmentTemplateFilterTypeDef,
    EnvironmentTemplateSummaryTypeDef,
    EnvironmentTemplateVersionSummaryTypeDef,
    GetEnvironmentAccountConnectionInputRequestTypeDef,
    WaiterConfigTypeDef,
    GetEnvironmentInputRequestTypeDef,
    GetEnvironmentTemplateInputRequestTypeDef,
    GetEnvironmentTemplateVersionInputRequestTypeDef,
    GetRepositoryInputRequestTypeDef,
    GetRepositorySyncStatusInputRequestTypeDef,
    GetServiceInputRequestTypeDef,
    GetServiceInstanceInputRequestTypeDef,
    GetServiceTemplateInputRequestTypeDef,
    GetServiceTemplateVersionInputRequestTypeDef,
    GetTemplateSyncConfigInputRequestTypeDef,
    GetTemplateSyncStatusInputRequestTypeDef,
    RevisionTypeDef,
    PaginatorConfigTypeDef,
    ListEnvironmentAccountConnectionsInputRequestTypeDef,
    ListEnvironmentOutputsInputRequestTypeDef,
    OutputTypeDef,
    ListEnvironmentProvisionedResourcesInputRequestTypeDef,
    ProvisionedResourceTypeDef,
    ListEnvironmentTemplateVersionsInputRequestTypeDef,
    ListEnvironmentTemplatesInputRequestTypeDef,
    ListRepositoriesInputRequestTypeDef,
    RepositorySummaryTypeDef,
    ListRepositorySyncDefinitionsInputRequestTypeDef,
    RepositorySyncDefinitionTypeDef,
    ListServiceInstanceOutputsInputRequestTypeDef,
    ListServiceInstanceProvisionedResourcesInputRequestTypeDef,
    ListServiceInstancesInputRequestTypeDef,
    ServiceInstanceSummaryTypeDef,
    ListServicePipelineOutputsInputRequestTypeDef,
    ListServicePipelineProvisionedResourcesInputRequestTypeDef,
    ListServiceTemplateVersionsInputRequestTypeDef,
    ServiceTemplateVersionSummaryTypeDef,
    ListServiceTemplatesInputRequestTypeDef,
    ServiceTemplateSummaryTypeDef,
    ListServicesInputRequestTypeDef,
    ServiceSummaryTypeDef,
    ListTagsForResourceInputRequestTypeDef,
    RejectEnvironmentAccountConnectionInputRequestTypeDef,
    RepositorySyncEventTypeDef,
    ResourceSyncEventTypeDef,
    S3ObjectSourceTypeDef,
    UntagResourceInputRequestTypeDef,
    UpdateEnvironmentAccountConnectionInputRequestTypeDef,
    UpdateEnvironmentTemplateInputRequestTypeDef,
    UpdateEnvironmentTemplateVersionInputRequestTypeDef,
    UpdateServiceInputRequestTypeDef,
    UpdateServiceInstanceInputRequestTypeDef,
    UpdateServicePipelineInputRequestTypeDef,
    UpdateServiceTemplateInputRequestTypeDef,
    UpdateTemplateSyncConfigInputRequestTypeDef,
    AcceptEnvironmentAccountConnectionOutputTypeDef,
    CreateEnvironmentAccountConnectionOutputTypeDef,
    DeleteEnvironmentAccountConnectionOutputTypeDef,
    GetEnvironmentAccountConnectionOutputTypeDef,
    RejectEnvironmentAccountConnectionOutputTypeDef,
    UpdateEnvironmentAccountConnectionOutputTypeDef,
    AccountSettingsTypeDef,
    EnvironmentTypeDef,
    CancelServiceInstanceDeploymentOutputTypeDef,
    GetServiceInstanceOutputTypeDef,
    UpdateServiceInstanceOutputTypeDef,
    CancelServicePipelineDeploymentOutputTypeDef,
    ServiceTypeDef,
    UpdateServicePipelineOutputTypeDef,
    UpdateServiceTemplateVersionInputRequestTypeDef,
    ServiceTemplateVersionTypeDef,
    CreateEnvironmentAccountConnectionInputRequestTypeDef,
    CreateEnvironmentTemplateInputRequestTypeDef,
    CreateServiceInputRequestTypeDef,
    CreateServiceTemplateInputRequestTypeDef,
    ListTagsForResourceOutputTypeDef,
    TagResourceInputRequestTypeDef,
    CreateEnvironmentInputRequestTypeDef,
    UpdateAccountSettingsInputRequestTypeDef,
    UpdateEnvironmentInputRequestTypeDef,
    CreateEnvironmentTemplateOutputTypeDef,
    DeleteEnvironmentTemplateOutputTypeDef,
    GetEnvironmentTemplateOutputTypeDef,
    UpdateEnvironmentTemplateOutputTypeDef,
    CreateEnvironmentTemplateVersionOutputTypeDef,
    DeleteEnvironmentTemplateVersionOutputTypeDef,
    GetEnvironmentTemplateVersionOutputTypeDef,
    UpdateEnvironmentTemplateVersionOutputTypeDef,
    CreateRepositoryOutputTypeDef,
    DeleteRepositoryOutputTypeDef,
    GetRepositoryOutputTypeDef,
    CreateServiceTemplateOutputTypeDef,
    DeleteServiceTemplateOutputTypeDef,
    GetServiceTemplateOutputTypeDef,
    UpdateServiceTemplateOutputTypeDef,
    CreateTemplateSyncConfigOutputTypeDef,
    DeleteTemplateSyncConfigOutputTypeDef,
    GetTemplateSyncConfigOutputTypeDef,
    UpdateTemplateSyncConfigOutputTypeDef,
    ListEnvironmentAccountConnectionsOutputTypeDef,
    ListEnvironmentsOutputTypeDef,
    ListEnvironmentsInputRequestTypeDef,
    ListEnvironmentTemplatesOutputTypeDef,
    ListEnvironmentTemplateVersionsOutputTypeDef,
    GetEnvironmentInputEnvironmentDeployedWaitTypeDef,
    GetEnvironmentTemplateVersionInputEnvironmentTemplateVersionRegisteredWaitTypeDef,
    GetServiceInputServiceCreatedWaitTypeDef,
    GetServiceInputServiceDeletedWaitTypeDef,
    GetServiceInputServicePipelineDeployedWaitTypeDef,
    GetServiceInputServiceUpdatedWaitTypeDef,
    GetServiceInstanceInputServiceInstanceDeployedWaitTypeDef,
    GetServiceTemplateVersionInputServiceTemplateVersionRegisteredWaitTypeDef,
    ListEnvironmentAccountConnectionsInputListEnvironmentAccountConnectionsPaginateTypeDef,
    ListEnvironmentOutputsInputListEnvironmentOutputsPaginateTypeDef,
    ListEnvironmentProvisionedResourcesInputListEnvironmentProvisionedResourcesPaginateTypeDef,
    ListEnvironmentTemplateVersionsInputListEnvironmentTemplateVersionsPaginateTypeDef,
    ListEnvironmentTemplatesInputListEnvironmentTemplatesPaginateTypeDef,
    ListEnvironmentsInputListEnvironmentsPaginateTypeDef,
    ListRepositoriesInputListRepositoriesPaginateTypeDef,
    ListRepositorySyncDefinitionsInputListRepositorySyncDefinitionsPaginateTypeDef,
    ListServiceInstanceOutputsInputListServiceInstanceOutputsPaginateTypeDef,
    ListServiceInstanceProvisionedResourcesInputListServiceInstanceProvisionedResourcesPaginateTypeDef,
    ListServiceInstancesInputListServiceInstancesPaginateTypeDef,
    ListServicePipelineOutputsInputListServicePipelineOutputsPaginateTypeDef,
    ListServicePipelineProvisionedResourcesInputListServicePipelineProvisionedResourcesPaginateTypeDef,
    ListServiceTemplateVersionsInputListServiceTemplateVersionsPaginateTypeDef,
    ListServiceTemplatesInputListServiceTemplatesPaginateTypeDef,
    ListServicesInputListServicesPaginateTypeDef,
    ListTagsForResourceInputListTagsForResourcePaginateTypeDef,
    ListEnvironmentOutputsOutputTypeDef,
    ListServiceInstanceOutputsOutputTypeDef,
    ListServicePipelineOutputsOutputTypeDef,
    NotifyResourceDeploymentStatusChangeInputRequestTypeDef,
    ListEnvironmentProvisionedResourcesOutputTypeDef,
    ListServiceInstanceProvisionedResourcesOutputTypeDef,
    ListServicePipelineProvisionedResourcesOutputTypeDef,
    ListRepositoriesOutputTypeDef,
    ListRepositorySyncDefinitionsOutputTypeDef,
    ListServiceInstancesOutputTypeDef,
    ListServiceTemplateVersionsOutputTypeDef,
    ListServiceTemplatesOutputTypeDef,
    ListServicesOutputTypeDef,
    RepositorySyncAttemptTypeDef,
    ResourceSyncAttemptTypeDef,
    TemplateVersionSourceInputTypeDef,
    GetAccountSettingsOutputTypeDef,
    UpdateAccountSettingsOutputTypeDef,
    CancelEnvironmentDeploymentOutputTypeDef,
    CreateEnvironmentOutputTypeDef,
    DeleteEnvironmentOutputTypeDef,
    GetEnvironmentOutputTypeDef,
    UpdateEnvironmentOutputTypeDef,
    CreateServiceOutputTypeDef,
    DeleteServiceOutputTypeDef,
    GetServiceOutputTypeDef,
    UpdateServiceOutputTypeDef,
    CreateServiceTemplateVersionOutputTypeDef,
    DeleteServiceTemplateVersionOutputTypeDef,
    GetServiceTemplateVersionOutputTypeDef,
    UpdateServiceTemplateVersionOutputTypeDef,
    GetRepositorySyncStatusOutputTypeDef,
    GetTemplateSyncStatusOutputTypeDef,
    CreateEnvironmentTemplateVersionInputRequestTypeDef,
    CreateServiceTemplateVersionInputRequestTypeDef,
)

def get_structure() -> AcceptEnvironmentAccountConnectionInputRequestTypeDef:
    return {
      ...
    }
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-proton` version is the same as related `aiobotocore` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_proton/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
